
# geizhals
Get the best prices from geizhals.

# Usage
```
define my_product_i_want_to_buy fhempy geizhals URL
```

URL: e.g. https://geizhals.at/google-pixel-6-pro-128gb-cloudy-white-a2623312.html

Example
```
define pixel fhempy geizhals https://geizhals.at/google-pixel-6-pro-128gb-cloudy-white-a2623312.html
```
